@@ -13,6 +13,7 @@ NULL
 #' This function checks library dependencies
 #'
 #' @family Tools
+#' @inheritParams cache_write
 #' @param package Character. Name of the library
 #' @param stop Boolean. Stop if not installed. If \code{FALSE} and
 #' library is not available, warning will be shown.
@@ -21,7 +22,6 @@ NULL
 #' to search through, or \code{NULL}. The default value of \code{NULL}
 #' corresponds to all libraries currently known to \code{.libPaths()}.
 #' Non-existent library trees are silently ignored.
-#' @param ... Pass additional parameters.
 #' @return No return value, called for side effects.
 #' @examples
 #' # Check if library base is installed. If not, stop and show error
@@ -473,7 +473,9 @@ autoline <- function(text, top = "auto", rel = 9) {
 #' To list all available fonts, set \code{font = NULL}.
 #'
 #' @family Tools
-#' @param font Character. Which font to check. 
+#' @inheritParams cache_write
+#' @param font Character. Which font to check. No need to add .TFF.
+#' @param font_dirs Character vector. Additional directories to check for fonts.
 #' @param quiet Boolean. Keep quiet? If not, show message
 #' @return Boolean result of the existing fonts check.
 #' @examples
@@ -482,68 +484,11 @@ autoline <- function(text, top = "auto", rel = 9) {
 #' font_exists(font = "")
 #' font_exists(font = NULL)
 #' @export
-font_exists <- function(font = "Arial Narrow", quiet = FALSE) {
-  if (isTRUE(font == "")) {
-    return(FALSE)
-  }
-  if (isTRUE(is.na(font))) {
-    return(FALSE)
-  }
-
+font_exists <- function(font = "Arial Narrow", font_dirs = NULL, quiet = FALSE, ...) {
+  if (isTRUE(font[1] == "")) return(FALSE)
+  if (isTRUE(is.na(font[1]))) return(FALSE)
   tryCatch(
-    {
-      # Thanks to extrafont for the idea for this code
-      ttf_find_default_path <- function() {
-        if (grepl("^darwin", R.version$os)) {
-          paths <- c(
-            "/Library/Fonts/",
-            "/System/Library/Fonts",
-            "/System/Library/Fonts/Supplemental",
-            "~/Library/Fonts/"
-          )
-          return(paths[file.exists(paths)])
-        } else if (grepl("^linux-gnu", R.version$os)) {
-          # Possible font paths, depending on the system
-          paths <- c(
-            "/usr/share/fonts/",
-            "/usr/X11R6/lib/X11/fonts/TrueType/",
-            "~/.fonts/"
-          )
-          return(paths[file.exists(paths)])
-        } else if (grepl("^freebsd", R.version$os)) {
-          # Possible font paths, depending on installed ports
-          paths <- c(
-            "/usr/local/share/fonts/truetype/",
-            "/usr/local/lib/X11/fonts/",
-            "~/.fonts/"
-          )
-          return(paths[file.exists(paths)])
-        } else if (grepl("^mingw", R.version$os)) {
-          return(paste(Sys.getenv("SystemRoot"), "\\Fonts", sep = ""))
-        } else {
-          stop("Unknown platform. Don't know where to look for truetype fonts. Sorry!")
-        }
-      }
-      check <- function(font, quiet = FALSE) {
-        pattern <- "\\.ttf$|\\.otf"
-        fonts_path <- ttf_find_default_path()
-        ttfiles <- list.files(fonts_path,
-          pattern = pattern,
-          full.names = TRUE, ignore.case = TRUE
-        )
-        font_names <- basename(ttfiles)
-        if (!is.null(font)) 
-          ret <- font %in% gsub(pattern, "", font_names) else ret <- FALSE
-        if (!quiet & !ret) {
-          if (!is.null(font)) font_names <- font_names[grepl(tolower(font), tolower(font_names))]
-          if (length(font_names) > 0)
-            message("Maybe you meant one of these: ",
-                    v2t(sort(gsub("\\..*", "", font_names))))
-        }
-        return(ret)
-      }
-      check(font)
-    },
+    check_font(font, font_dirs, quiet),
     error = function(err) {
       if (!quiet) message(paste("Font issue:", err))
       return(FALSE)
@@ -551,6 +496,64 @@ font_exists <- function(font = "Arial Narrow", quiet = FALSE) {
   )
 }
 
+# Thanks to extrafont for the idea for this code
+ttf_find_default_path <- function(font_dirs = NULL) {
+  if (grepl("^darwin", R.version$os)) {
+    paths <-
+      c("/Library/Fonts/",                      # System fonts
+        "/System/Library/Fonts",                # More system fonts
+        "/System/Library/Fonts/Supplemental",   # More system fonts
+        "~/Library/Fonts/",                     # User fonts
+        font_dirs)
+    return(paths[file.exists(paths)])
+  } else if (grepl("^linux-gnu", R.version$os)) {
+    paths <-
+      c("/usr/share/fonts/",                    # Ubuntu/Debian/Arch/Gentoo
+        "/usr/local/share/fonts/",              # system-admin-guide/stable/fonts.html.en
+        "/usr/X11R6/lib/X11/fonts/TrueType/",   # RH 6
+        "~/.local/share/fonts/",                # Added with Gnome font viewer
+        "~/.fonts/",                            # User fonts
+        font_dirs)
+    return(paths[file.exists(paths)])
+  } else if (grepl("^freebsd", R.version$os)) {
+    # Possible font paths, depending on installed ports
+    paths <-
+      c("/usr/local/share/fonts/truetype/",
+        "/usr/local/lib/X11/fonts/",
+        "~/.fonts/",                            # User fonts
+        font_dirs)
+    return(paths[file.exists(paths)])
+  } else if (grepl("^mingw", R.version$os)) {
+    paths <-
+      c(file.path(Sys.getenv("SystemRoot"), "Fonts"),
+        file.path(Sys.getenv("LOCALAPPDATA"), "Microsoft", "Windows", "Fonts"),
+        font_dirs)
+    return(paths[file.exists(paths)])
+  } else {
+    stop("Unknown platform. Don't know where to look for truetype fonts. Sorry!")
+  }
+}
+
+check_font <- function(font, font_dirs = NULL, quiet = FALSE) {
+  pattern <- "\\.ttf$|\\.otf"
+  fonts_path <- ttf_find_default_path(font_dirs)
+  ttfiles <- list.files(fonts_path,
+                        pattern = pattern, recursive = TRUE,
+                        full.names = TRUE, ignore.case = TRUE
+  )
+  font_names <- basename(ttfiles)
+  nice_names <- gsub(pattern, "", font_names, ignore.case = TRUE)
+  if (is.null(font)) return(nice_names)
+  ret <- font %in% nice_names
+  if (!quiet & !all(ret)) {
+    if (!is.null(font)) font_names <- font_names[
+      grepl(tolower(paste(font, collapse = "|")), tolower(font_names))]
+    if (length(font_names) > 0)
+      message("Maybe you meant one of these:\n", v2t(sort(gsub("\\..*", "", font_names))))
+  }
+  return(ret)
+}
+
 
 ####################################################################
 #' List categorical values for data.frame
@@ -985,17 +988,20 @@ what_size <- function(x = NULL, units = "Mb", path = NULL, recursive = TRUE, ...
   }
 }
 
-dir_size <- function(path, recursive = TRUE, pattern = NULL, ...) {
+dir_size <- function(path = getwd(), recursive = TRUE, pattern = NULL, ...) {
   stopifnot(is.character(path))
   stopifnot(dir.exists(path))
-  files <- list.files(
-    path = path, pattern = pattern,
-    recursive = recursive, full.names = TRUE)
-  size_files <- 0
-  if (length(files) > 0) {
-    vect_size <- sapply(files, function(x) file.size(x))
-    size_files <- sum(vect_size, na.rm = TRUE)
-  }
+  # files <- list.files(
+  #   path = path, pattern = pattern,
+  #   recursive = recursive, full.names = TRUE)
+  # size_files <- 0
+  # if (length(files) > 0) {
+  #   vect_size <- sapply(files, function(x) file.size(x))
+  #   size_files <- sum(vect_size, na.rm = TRUE)
+  # }
+  size_files <- system(paste("du -hs", path), intern = TRUE)
+  size_files <- gsub("\\\t.*", "", size_files)
+  size_files <- num_abbr(size_files, numeric = TRUE)
   class(size_files) <- "object_size"
   return(size_files)
 }
