@@ -137,7 +137,6 @@ plot_timeline <- function(event,
                           interactive = FALSE,
                           save = FALSE,
                           subdir = NA) {
-
   # Let's gather all the data
   df <- data.frame(
     Role = as.character(event),
@@ -174,7 +173,7 @@ plot_timeline <- function(event,
     )
   # scale_x_date(expand = c(0, 0))
 
-  if (!is.na(cvlong$type)[1] | length(unique(cvlong$type)) > 1) {
+  if (!is.na(cvlong$type)[1] || length(unique(cvlong$type)) > 1) {
     p <- p + geom_line(aes(colour = .data$type), size = 7) +
       facet_grid(.data$type ~ ., scales = "free", space = "free") +
       guides(colour = "none")
